==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1DaemonSetUpdateStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V1DaemonSetUpdateStrategyFluent<A extends V1DaemonSetUpdateStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public V1RollingUpdateDaemonSet getRollingUpdate();
    public V1RollingUpdateDaemonSet buildRollingUpdate();
    public A withRollingUpdate(V1RollingUpdateDaemonSet rollingUpdate);
    public Boolean hasRollingUpdate();
    public V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(V1RollingUpdateDaemonSet item);
    public V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(V1RollingUpdateDaemonSet item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1RollingUpdateDaemonSetFluent<V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1DaemonSetUpdateStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1DaemonSetUpdateStrategyFluent<A extends V1DaemonSetUpdateStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public V1RollingUpdateDaemonSet getRollingUpdate();
    public V1RollingUpdateDaemonSet buildRollingUpdate();
    public A withRollingUpdate(V1RollingUpdateDaemonSet rollingUpdate);
    public Boolean hasRollingUpdate();
    public V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(V1RollingUpdateDaemonSet item);
    public V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(V1RollingUpdateDaemonSet item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1RollingUpdateDaemonSetFluent<V1DaemonSetUpdateStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}
